<div class="d-flex flex-row justify-content-between my-2">
  {% if actions %}
    <div class="d-flex justify-content-start">
      {% include templates.tb_actions %}
    </div>
  {% endif %}
  <div class="d-sm-flex {% if actions %}justify-content-middle{% else %}justify-content-start{% endif %}">
    <div class="d-sm-none d-lg-block">
      {% include templates.tb_buttons %}
    </div>
    <div class="d-flex justify-content-end">
      <div class="btn-group">
        {% include templates.tb_filter_button %}
        {% include templates.tb_columns %}
        {% include templates.tb_rows %}
      </div>
    </div>
  </div>
</div>