{% block table_header %}
{#  {% include "django_tableaux/bootstrap4/render_header.html" %}#}
  {% include templates.render_header %}
{% endblock table_header %}
{% block table_body %}
  <tbody {{ table.attrs.tbody.as_html }}>
  {% include templates.render_body %}
  </tbody>
{% endblock table_body %}
{% block table_footer %}
  {% include templates.render_footer %}
{% endblock table_footer %}

