# Generated by Django 5.0.6 on 2025-01-18 16:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('myapp', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='TestModel',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('a', models.CharField(max_length=20)),
                ('b', models.CharField(max_length=20)),
                ('c', models.CharField(max_length=20)),
                ('d', models.CharField(max_length=20)),
            ],
        ),
    ]
